Configuration Files — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Configuration Files

The configuration files in `pyprocar/cfg/` help customize the plotting options for our code base. Each YAML file contains settings related to plotting properties.

Below are descriptions for some of the keys you might find in these files. cfg ===================================

This chapter is intended to describe data types that are used to assist in the processing of the electronic structure

PyProcar has the following data types:

- `pyprocar/cfg/band_structure.yml` : Controls the plotting options for the band structure plots

- `pyprocar/cfg/band_structure_2d.yml` : Controls the plotting options for the band structure 2d plots

- `pyprocar/cfg/dos.yml` : Controls the plotting options for the density of states plots

- `pyprocar/cfg/fermi_surface_3d.yml` : Controls the plotting options for the fermi surface 3d plots

- `pyprocar/cfg/fermi_surface_2d.yml` : Controls the plotting options for the fermi surface 2d plots

- Band Structure Configuration API
- band structure 2d plotting Options
- dos plotting Options
- unfold plotting Options
- Fermi Surface 3D Configuration API
- fermi surface 2d plotting Options